@@ -2,7 +2,7 @@
 from .asset_app import AssetApp
 from .datasource_app import DataSourceApp
 from .project_app import ProjectApp
-from .dataset_app import DataSetApp
 from .job_app import JobApp
 from .model_app import ModelApp
-from .pmod_app import PipelineModApp
\ No newline at end of file
+from .pmod_app import PipelineModApp
+from .clip_app import ClipApp
