@@ -9,7 +9,6 @@ __all__ = [
     'Asset',
     'FileImport',
     'FileUpload',
-    'Clip',
     'StoredFile',
     'FileTypes'
 ]
@@ -118,18 +117,67 @@ class DocumentMixin(object):
         else:
             self.set_attr(attr, json.loads(to_json(val)))
 
-    def get_analysis(self, name):
+    def get_analysis(self, namespace):
         """
         Return the the given analysis data under the the given name.
 
         Args:
-            name (str): The pipeline module name that generated the data.
+            namespace (str): The  model namespace / pipeline module name.
 
         Returns:
             dict: An arbitrary dictionary containing predictions, content, etc.
 
         """
-        return self.get_attr("analysis.{}".format(name))
+        name = getattr(namespace, "namespace", "analysis.{}".format(namespace))
+        return self.get_attr(name)
+
+    def get_predicted_labels(self, namespace, min_score=None):
+        """
+        Get all predictions made by the given label prediction module. If no
+        label predictions are present, returns None.
+
+        Args:
+            namespace (str): The analysis namespace, example 'zvi-label-detection'.
+            min_score (float): Filter results by a minimum score.
+
+        Returns:
+            list: A list of dictionaries containing the predictions
+
+        """
+        name = getattr(namespace, "namespace", "analysis.{}".format(namespace))
+        predictions = self.get_attr(f'{name}.predictions')
+        if not predictions:
+            return None
+        if min_score:
+            return [pred for pred in predictions if pred['score'] >= min_score]
+        else:
+            return predictions
+
+    def get_predicted_label(self, namespace, label):
+        """
+        Get a prediction made by the given label prediction module.  If no
+        label predictions are present, returns None.
+
+        Args:
+            namespace (str): The model / module name that created the prediction.
+            label (mixed): A label name or integer index of a prediction.
+
+        Returns:
+            dict: a prediction dict with a label, score, etc.
+        """
+
+        preds = self.get_predicted_labels(namespace)
+        if not preds:
+            return None
+
+        if isinstance(label, str):
+            preds = [pred for pred in preds if pred['label'] == label]
+            label = 0
+
+        try:
+            return preds[label]
+        except IndexError:
+            return None
 
     def extend_list_attr(self, attr, items):
         """
@@ -185,7 +233,7 @@ class FileImport(object):
     An FileImport is used to import a new file and metadata into ZMLP.
     """
 
-    def __init__(self, uri, attrs=None, clip=None, label=None):
+    def __init__(self, uri, attrs=None, page=None, label=None):
         """
         Construct an FileImport instance which can point to a remote URI.
 
@@ -193,15 +241,14 @@ class FileImport(object):
             uri (str): a URI locator to the file asset.
             attrs (dict): A shallow key/value pair dictionary of starting point
                 attributes to set on the asset.
-            clip (Clip): Defines a subset of the asset to be processed, for example a
-                page of a PDF or time code from a video.
-            label (DataSetLabel): An optional dataset label which will add the file to
-                a DataSet automatically.
+            page (int): The specific page to import if any.
+            label (Label): An optional Label which will add the file to
+                a Model training set.
         """
         super(FileImport, self).__init__()
         self.uri = uri
         self.attrs = attrs or {}
-        self.clip = clip
+        self.page = page
         self.label = label
 
     def for_json(self):
@@ -216,7 +263,7 @@ class FileImport(object):
         return {
             "uri": self.uri,
             "attrs": self.attrs,
-            "clip": self.clip,
+            "page": self.page,
             "label": self.label
         }
 
@@ -232,7 +279,7 @@ class FileUpload(FileImport):
     FileUpload instances point to a local file that will be uploaded for analysis.
     """
 
-    def __init__(self, path, attrs=None, clip=None, label=None):
+    def __init__(self, path, attrs=None, page=None, label=None):
         """
         Create a new FileUpload instance.
 
@@ -240,12 +287,12 @@ class FileUpload(FileImport):
             path (str): A path to a file, the file must exist.
             attrs (dict): A shallow key/value pair dictionary of starting point
                 attributes to set on the asset.
-            clip (Clip): Clip settings if applicable.
-            label (DataSetLabel): An optional dataset label which will add the file to
-                a DataSet automatically.
+            page (int): The specific page to import if any.
+            label (Label): An optional Label which will add the file to
+                a Model training set.
         """
         super(FileUpload, self).__init__(
-            os.path.normpath(os.path.abspath(path)), attrs, clip, label)
+            os.path.normpath(os.path.abspath(path)), attrs, page, label)
 
         if not os.path.exists(path):
             raise ValueError('The path "{}" does not exist'.format(path))
@@ -261,18 +308,17 @@ class FileUpload(FileImport):
         """
         return {
             "uri": self.uri,
-            "clip": self.clip,
+            "page": self.page,
             "label": self.label
         }
 
 
 class Asset(DocumentMixin):
     """
-    An Asset represents a single processed file or a clip/segment of a
-    file. Assets start out in the 'CREATED' state, which indicates
-    they've been created by not processed.  Once an asset has been processed
-    and augmented with files created by various analysis modules, the Asset
-    will move into the 'ANALYZED' state.
+    An Asset represents a single processed file.  Assets start out
+    in the 'CREATED' state, which indicates they've been created by not processed.
+    Once an asset has been processed and augmented with files created by various
+    analysis modules, the Asset will move into the 'ANALYZED' state.
     """
 
     def __init__(self, data):
@@ -312,6 +358,17 @@ class Asset(DocumentMixin):
         """
         return self.get_attr("source.path")
 
+    @property
+    def extension(self):
+        """
+        The file extension of the asset, lower cases.
+
+        Returns:
+            str: The file extension
+
+        """
+        return self.get_attr("source.extension").lower()
+
     def add_file(self, stored_file):
         """
         Adds the StoredFile record to the asset's list of associated files.
@@ -437,7 +494,8 @@ class Asset(DocumentMixin):
         return {
             "id": self.id,
             "uri": self.get_attr("source.path"),
-            "document": self.document
+            "document": self.document,
+            "page": self.get_attr("media.pageNumber"),
         }
 
     def __str__(self):
@@ -455,76 +513,6 @@ class Asset(DocumentMixin):
         return other.id == self.id
 
 
-class Clip(object):
-    """
-    A Clip object is used to define a subsection of a file/asset that should be
-    processed, for example a particular page of a PDF or a section of a movie.
-
-    Each clip of an Asset needs to have a unique type, start, stop, and optionally
-    track attributes fo it to be considered a unique clip.
-
-    """
-
-    @staticmethod
-    def page(page_num):
-        """
-        Return a standard 'page' clip for the given page.
-
-        Args:
-            page_num (int): The page number
-
-        Returns:
-            Clip: The page clip.
-
-        """
-        return Clip('page', page_num, page_num)
-
-    @staticmethod
-    def scene(time_in, time_out, track):
-        """
-        Return a video scene Clip with the given in/out points and a track name.
-
-        Args:
-            time_in: (float): The start time of the cut.
-            time_out: (float): The end time of the cut.
-            track: (str): An track label.  Videos can be clipified multiple ways
-                by multiple types of services and labeling them with a track is
-                useful for differentiating them.
-        Returns:
-            Clip: A scene Clip.
-
-        """
-        return Clip('scene', time_in, time_out, track)
-
-    def __init__(self, type, start, stop, track=None):
-        """Initialize a new clip.
-
-        Args:
-            type (str): The clip type, usually 'scene' or 'page' but it can be arbitrary.
-            start (float): The start of the clip
-            stop (float): The end of the clip,
-            track (str): The track the clip belongs to.
-        """
-
-        self.type = type
-        self.start = float(start)
-        self.stop = float(stop)
-        self.track = track
-
-    def for_json(self):
-        """Return a JSON serialized copy.
-
-        Returns:
-            :obj:`dict`: A json serializable dict.
-        """
-        serializable_dict = {}
-        attrs = ['type', 'start', 'stop', 'track']
-        for attr in attrs:
-            if getattr(self, attr, None) is not None:
-                serializable_dict[attr] = getattr(self, attr)
-        return serializable_dict
-
-
 class StoredFile(object):
     """
     The StoredFile class represents a supporting file that has been stored in ZVI.
@@ -611,7 +599,7 @@ class FileTypes:
     A class for storing the supported file types.
     """
 
-    videos = frozenset(['mov', 'mp4', 'mpg', 'mpeg', 'm4v', 'webm', 'ogv', 'ogg', 'mxf'])
+    videos = frozenset(['mov', 'mp4', 'mpg', 'mpeg', 'm4v', 'webm', 'ogv', 'mxf'])
     """A set of supported video file formats."""
 
     images = frozenset(["bmp", "cin", "dpx", "gif", "jpg",
